@@ -138,6 +138,15 @@
 #'
 #' @param xlab text label for the horizontal plot axis
 #' 
+#' @param hide vector with indices of aliquots that should be removed
+#'     from the plot.
+#' 
+#' @param omit vector with indices of aliquots that should be plotted
+#'     but omitted from the isochron age calculation.
+#' 
+#' @param omit.col colour that should be used for the omitted
+#'     aliquots.
+#' 
 #' @param ylab text label for the vertical plot axis
 #' 
 #' @seealso
@@ -180,16 +189,21 @@ isochron.default <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                              show.numbers=FALSE,levels=NA,clabel="",
                              ellipse.col=c("#00FF0080","#FF000080"),
                              ci.col='gray80',line.col='black',lwd=1,
-                             plot=TRUE,title=TRUE,model=1,
-                             xlab='x',ylab='y',...){
-    fit <- regression_init(x,model=model,alpha=alpha)
-    fit <- ci_isochron(fit,model=model,alpha=alpha)
+                             plot=TRUE,title=TRUE,model=1,xlab='x',
+                             ylab='y',hide=NULL,omit=NULL,
+                             omit.col=NA,...){
+    d <- data2york(x)
+    d2calc <- clear(x,hide,omit)
+    fit <- regression(d2calc,model=model)
+    fit <- regression_init(fit,alpha=alpha)
+    fit <- ci_isochron(fit)
     if (plot){
-        scatterplot(fit$d,xlim=xlim,ylim=ylim,alpha=alpha,
+        scatterplot(d,xlim=xlim,ylim=ylim,alpha=alpha,
                     show.ellipses=1*(model!=2),
                     show.numbers=show.numbers,levels=levels,
                     clabel=clabel,ellipse.col=ellipse.col,fit=fit,
-                    ci.col=ci.col,line.col=line.col,lwd=lwd,...)
+                    ci.col=ci.col,line.col=line.col,lwd=lwd,
+                    hide=hide,omit=omit,omit.col=omit.col,...)
         if (title) graphics::title(isochrontitle(fit,sigdig=sigdig),
                                    xlab=xlab,ylab=ylab)
     }
@@ -370,8 +384,12 @@ isochron.ArAr <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
                           inverse=TRUE,ci.col='gray80',line.col='black',
-                          lwd=1,plot=TRUE,exterr=TRUE,model=1,...){
-    out <- isochron_init(x,model=model,inverse=inverse,alpha=alpha)
+                          lwd=1,plot=TRUE,exterr=TRUE,model=1,
+                          hide=NULL,omit=NULL,omit.col=NA,...){
+    d <- data2york(x,inverse=inverse)
+    d2calc <- clear(d,hide,omit)
+    fit <- regression(d2calc,model=model)
+    out <- isochron_init(fit,alpha=alpha)
     a <- out$a['a']
     sa <- out$a['s[a]']
     b <- out$b['b']
@@ -396,18 +414,19 @@ isochron.ArAr <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
     out$y0label <- quote('('^40*'Ar/'^36*'Ar)'[o]*' = ')
     out$age[c('t','s[t]')] <-
         get.ArAr.age(R09,sR09,x$J[1],x$J[2],exterr=exterr)
-    out <- ci_isochron(out,model=model,alpha=alpha)
+    out <- ci_isochron(out)
     if (model==1){
         out$age['disp[t]'] <-
             out$fact*get.ArAr.age(R09,sqrt(out$mswd)*sR09,
                                   x$J[1],x$J[2],exterr=exterr)[2]
     }
     if (plot) {
-        scatterplot(out$d,xlim=xlim,ylim=ylim,alpha=alpha,
+        scatterplot(d,xlim=xlim,ylim=ylim,alpha=alpha,
                     show.ellipses=1*(model!=2),
                     show.numbers=show.numbers,levels=levels,
-                    clabel=clabel,ellipse.col=ellipse.col,
-                    fit=out,ci.col=ci.col,line.col=line.col,lwd=lwd,...)
+                    clabel=clabel,ellipse.col=ellipse.col,fit=out,
+                    ci.col=ci.col,line.col=line.col,lwd=lwd,
+                    hide=hide,omit=omit,omit.col=omit.col,...)
         graphics::title(isochrontitle(out,sigdig=sigdig,type='Ar-Ar'),
                         xlab=x.lab,ylab=y.lab)
     }
@@ -419,12 +438,14 @@ isochron.KCa <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                          show.numbers=FALSE,levels=NA,clabel="",
                          ellipse.col=c("#00FF0080","#FF000080"),
                          ci.col='gray80',line.col='black',
-                         lwd=1,plot=TRUE,exterr=TRUE,model=1,...){
+                         lwd=1,plot=TRUE,exterr=TRUE,model=1,
+                         hide=NULL,omit=NULL,omit.col=NA,...){
     isochron_PD(x,'K40',xlim=xlim,ylim=ylim,alpha=alpha,
                 sigdig=sigdig,show.numbers=show.numbers,
                 levels=levels,clabel=clabel,ellipse.col=ellipse.col,
                 ci.col=ci.col,line.col=line.col,lwd=lwd,
-                plot=plot,exterr=exterr,model=model,bratio=0.895,...)
+                plot=plot,exterr=exterr,model=model,bratio=0.895,
+                hide=hide,omit=omit,omit.col=omit.col,...)
 }
 #' @param growth add Stacey-Kramers Pb-evolution curve to the plot?
 #' @rdname isochron
@@ -434,8 +455,12 @@ isochron.PbPb <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           ellipse.col=c("#00FF0080","#FF000080"),
                           inverse=TRUE,ci.col='gray80',
                           line.col='black',lwd=1,plot=TRUE,
-                          exterr=TRUE,model=1,growth=FALSE,...){
-    out <- isochron_init(x,model=model,inverse=inverse,alpha=alpha)
+                          exterr=TRUE,model=1,growth=FALSE,
+                          hide=NULL,omit=NULL,omit.col=NA,...){
+    d <- data2york(x,inverse=inverse)
+    d2calc <- clear(d,hide,omit)
+    fit <- regression(d2calc,model=model)
+    out <- isochron_init(fit,alpha=alpha)
     if (inverse){
         R76 <- out$a
         out$y0[c('y','s[y]')] <- out$b
@@ -452,18 +477,19 @@ isochron.PbPb <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
     out$y0label <- quote('('^207*'Pb/'^204*'Pb)'[o]*' = ')
     out$age[c('t','s[t]')] <-
         get.Pb207Pb206.age(R76[1],R76[2],exterr=exterr)
-    out <- ci_isochron(out,model=model,alpha=alpha)
+    out <- ci_isochron(out)
     if (model==1){
         out$age['disp[t]'] <-
             out$fact*get.Pb207Pb206.age(R76[1],sqrt(out$mswd)*R76[2],
                                         exterr=exterr)[2]
     }
     if (plot) {
-        scatterplot(out$d,xlim=xlim,ylim=ylim,alpha=alpha,
+        scatterplot(d,xlim=xlim,ylim=ylim,alpha=alpha,
                     show.ellipses=1*(model!=2),
                     show.numbers=show.numbers,levels=levels,
                     clabel=clabel,ellipse.col=ellipse.col,fit=out,
-                    ci.col=ci.col,line.col=line.col,lwd=lwd,...)
+                    ci.col=ci.col,line.col=line.col,lwd=lwd,
+                    hide=hide,omit=omit,omit.col=omit.col,...)
         if (growth) plot_PbPb_evolution(out$age['t'],inverse=inverse)
         graphics::title(isochrontitle(out,sigdig=sigdig,type='Pb-Pb'),
                         xlab=x.lab,ylab=y.lab)
@@ -476,12 +502,14 @@ isochron.RbSr <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
                           ci.col='gray80',line.col='black',lwd=1,
-                          plot=TRUE,exterr=TRUE,model=1,...){
+                          plot=TRUE,exterr=TRUE,model=1,hide=NULL,
+                          omit=NULL,omit.col=NA,...){
     isochron_PD(x,'Rb87',xlim=xlim,ylim=ylim,alpha=alpha,
                 sigdig=sigdig,show.numbers=show.numbers,
                 levels=levels,clabel=clabel,ellipse.col=ellipse.col,
                 ci.col=ci.col,line.col=line.col,lwd=lwd,plot=plot,
-                exterr=exterr,model=model,...)
+                exterr=exterr,model=model,hide=hide,omit=omit,
+                omit.col=omit.col,...)
 }
 #' @rdname isochron
 #' @export
@@ -489,12 +517,14 @@ isochron.ReOs <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
                           ci.col='gray80',line.col='black',lwd=1,
-                          plot=TRUE,exterr=TRUE,model=1,...){
+                          plot=TRUE,exterr=TRUE,model=1,hide=NULL,
+                          omit=NULL,omit.col=NA,...){
     isochron_PD(x,'Re187',xlim=xlim,ylim=ylim,alpha=alpha,
                 sigdig=sigdig,show.numbers=show.numbers,
                 levels=levels,clabel=clabel,ellipse.col=ellipse.col,
-                ci.col=ci.col,line.col=line.col,lwd=lwd,
-                plot=plot,exterr=exterr,model=model,...)
+                ci.col=ci.col,line.col=line.col,lwd=lwd,plot=plot,
+                exterr=exterr,model=model,hide=hide,
+                omit=omit,omit.col=omit.col,...)
 }
 #' @rdname isochron
 #' @export
@@ -502,12 +532,14 @@ isochron.SmNd <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
                           ci.col='gray80',line.col='black',lwd=1,
-                          plot=TRUE,exterr=TRUE,model=1,...){
+                          plot=TRUE,exterr=TRUE,model=1,hide=NULL,
+                          omit=NULL,omit.col=NA,...){
     isochron_PD(x,'Sm147',xlim=xlim,ylim=ylim,alpha=alpha,
                 sigdig=sigdig,show.numbers=show.numbers,
                 levels=levels,clabel=clabel,ellipse.col=ellipse.col,
                 ci.col=ci.col,line.col=line.col,lwd=lwd,
-                plot=plot,exterr=exterr,model=model,...)
+                plot=plot,exterr=exterr,model=model,hide=hide,
+                omit=omit,omit.col=omit.col,...)
 }
 #' @rdname isochron
 #' @export
@@ -515,12 +547,14 @@ isochron.LuHf <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
                           ci.col='gray80',line.col='black',lwd=1,
-                          plot=TRUE,exterr=TRUE,model=1,...){
+                          plot=TRUE,exterr=TRUE,model=1,hide=NULL,
+                          omit=NULL,omit.col=NA,...){
     isochron_PD(x,'Lu176',xlim=xlim,ylim=ylim,alpha=alpha,
                 sigdig=sigdig,show.numbers=show.numbers,
                 levels=levels,clabel=clabel,ellipse.col=ellipse.col,
                 ci.col=ci.col,line.col=line.col,lwd=lwd,
-                plot=plot,exterr=exterr,model=model,...)
+                plot=plot,exterr=exterr,model=model,hide=hide,
+                omit=omit,omit.col=omit.col,...)
 }
 #' @param type following the classification of
 #' Ludwig and Titterington (1994), one of either:
@@ -546,14 +580,17 @@ isochron.ThU <- function (x,type=2,xlim=NA,ylim=NA,alpha=0.05,
                           sigdig=2,show.numbers=FALSE,levels=NA,
                           clabel="",ellipse.col=c("#00FF0080","#FF000080"),
                           ci.col='gray80',line.col='black',lwd=1,
-                          plot=TRUE,exterr=TRUE,model=1,...){
+                          plot=TRUE,exterr=TRUE,model=1,hide=NULL,
+                          omit=NULL,omit.col=NA,...){
     if (x$format %in% c(1,2)){
         out <- isochron_ThU_3D(x,type=type,model=model,
-                               exterr=exterr,alpha=alpha)
+                               exterr=exterr,alpha=alpha,
+                               hide=hide,omit=omit)
         intercept.type <- 'Th-U-3D'
     } else if (x$format %in% c(3,4)){
         out <- isochron_ThU_2D(x,type=type,model=model,
-                               exterr=exterr,alpha=alpha)
+                               exterr=exterr,alpha=alpha,
+                               hide=hide,omit=omit)
         intercept.type <- 'Th-U-2D'
     }
     if (type %in% c(1,3)){
@@ -566,7 +603,8 @@ isochron.ThU <- function (x,type=2,xlim=NA,ylim=NA,alpha=0.05,
                     show.ellipses=1*(model!=2),
                     show.numbers=show.numbers,levels=levels,
                     clabel=clabel,ellipse.col=ellipse.col,fit=out,
-                    ci.col=ci.col,line.col=line.col,lwd=lwd,...)
+                    ci.col=ci.col,line.col=line.col,lwd=lwd,
+                    hide=hide,omit=omit,omit.col=omit.col,...)
         graphics::title(isochrontitle(out,sigdig=sigdig,
                         type=intercept.type,units='ka'),
                         xlab=out$xlab,ylab=out$ylab)
@@ -577,27 +615,32 @@ isochron.ThU <- function (x,type=2,xlim=NA,ylim=NA,alpha=0.05,
 #' @export
 isochron.UThHe <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                            show.numbers=FALSE,ci.col='gray80',
-                           line.col='black',lwd=1,plot=TRUE,model=1,...){
-    out <- isochron_init(x,model=model,alpha=alpha)
+                           line.col='black',lwd=1,plot=TRUE,model=1,
+                           hide=NULL,omit=NULL,omit.col='grey',...){
+    d <- data2york(x)
+    d2calc <- clear(d,hide,omit)
+    fit <- regression(d2calc,model=model)
+    out <- isochron_init(fit,alpha=alpha)
     out$y0[c('y','s[y]')] <- out$a
     out$age[c('t','s[t]')] <- out$b
-    out <- ci_isochron(out,model=model,alpha=alpha)
+    out <- ci_isochron(out)
     if (model==1)
         out$age['disp[t]'] <- out$fact*sqrt(out$mswd)*out$age['s[t]']
     out$displabel <- quote('He-dispersion = ')
     out$y0label <- quote('He'[o]*' = ')
     if (plot) {
-        scatterplot(out$d,xlim=xlim,ylim=ylim,alpha=alpha,
+        scatterplot(d,xlim=xlim,ylim=ylim,alpha=alpha,
                     show.ellipses=2*(model!=2),show.numbers=show.numbers,
-                    fit=out,ci.col=ci.col,line.col=line.col,lwd=lwd,...)
+                    fit=out,ci.col=ci.col,line.col=line.col,lwd=lwd,
+                    hide=hide,omit=omit,omit.col=omit.col,...)
         graphics::title(isochrontitle(out,sigdig=sigdig,type='U-Th-He'),
                         xlab="P",ylab="He")
     }
     invisible(out)
 }
-    
-isochron_ThU_3D <- function(x,type=2,model=1,
-                            exterr=TRUE,alpha=0.05){
+
+isochron_ThU_3D <- function(x,type=2,model=1,exterr=TRUE,
+                            alpha=0.05,hide=NULL,omit=NULL){
     if (type == 1){
         osmond <- FALSE
         ia <- 'a'
@@ -635,7 +678,11 @@ isochron_ThU_3D <- function(x,type=2,model=1,
         x.lab <- quote(''^232*'Th/'^238*'U')
         y.lab <- quote(''^234*'U/'^238*'U')
     }
-    out <- isochron_init(x,model=model,alpha=alpha,osmond=osmond)
+    d <- data2tit(x,osmond=osmond)
+    d2calc <- clear(d,hide,omit)
+    fit <- regression(d2calc,model=model,type="titterington")
+    out <- isochron_init(fit,alpha=alpha)
+    out$d <- d
     out$a <- c(out$par[ia],sqrt(out$cov[ia,ia]))
     out$b <- c(out$par[ib],sqrt(out$cov[ib,ib]))
     out$cov.ab <- out$cov[ia,ib]
@@ -647,7 +694,7 @@ isochron_ThU_3D <- function(x,type=2,model=1,
     out$age['s[t]'] <- tst['s[t]']
     out$y0['s[y]'] <- tst['s[48_0]']
     out$y0label <- quote('('^234*'U/'^238*'U)'[o]*'=')
-    out <- ci_isochron(out,model=model,alpha=alpha,disp=FALSE)
+    out <- ci_isochron(out,disp=FALSE)
     if (model==1 && out$mswd>1){
         tdispt <- get.ThU.age(out$par[i08],
                               sqrt(out$mswd)*sqrt(out$cov[i08,i08]),
@@ -663,9 +710,13 @@ isochron_ThU_3D <- function(x,type=2,model=1,
     out$d <- subset(out$d,select=id)
     out
 }
-isochron_ThU_2D <- function(x,type=2,model=1,
-                            exterr=TRUE,alpha=0.05){
-    out <- isochron_init(x,model=model,type=type,alpha=alpha)
+isochron_ThU_2D <- function(x,type=2,model=1,exterr=TRUE,
+                            alpha=0.05,hide=NULL,omit=NULL){
+    d <- data2york(x,type=type)
+    d2calc <- clear(d,hide,omit)
+    fit <- regression(d2calc,model=model,type="york")
+    out <- isochron_init(fit,alpha=alpha)
+    out$d <- d
     if (type==1){
         Th230U238 <- out$b
         Th230Th232 <- out$a
@@ -682,7 +733,7 @@ isochron_ThU_2D <- function(x,type=2,model=1,
                     exterr=exterr)[c('t','s[t]')]
     out$y0[c('y','s[y]')] <-
         get.Th230Th232_0x(out$age['t'],Th230Th232[1],Th230Th232[2])
-    out <- ci_isochron(out,model=model,alpha=alpha,disp=FALSE)
+    out <- ci_isochron(out,disp=FALSE)
     if (model==1 && out$mswd>1){
         out$age['disp[t]'] <-
             out$fact*get.ThU.age(Th230U238[1],
@@ -701,13 +752,17 @@ isochron_PD <- function(x,nuclide,xlim=NA,ylim=NA,alpha=0.05,
                         sigdig=2,show.numbers=FALSE,levels=NA,
                         clabel="",ellipse.col=c("#00FF0080","#FF000080"),
                         ci.col='gray80',line.col='black',lwd=1,
-                        plot=TRUE,exterr=TRUE,model=1,bratio=1,...){
-    out <- isochron_init(x,model=model,exterr=exterr,alpha=alpha)
+                        plot=TRUE,exterr=TRUE,model=1,bratio=1,
+                        hide=NULL,omit=NULL,...){
+    d <- data2york(x)
+    d2calc <- clear(d,hide,omit)
+    fit <- regression(d2calc,model=model)
+    out <- isochron_init(fit,alpha=alpha)
     out$y0[c('y','s[y]')] <- out$a
     out$age[c('t','s[t]')] <- get.PD.age(out$b['b'],out$b['s[b]'],
                                          nuclide,exterr=exterr,
                                          bratio=bratio)
-    out <- ci_isochron(out,model=model,alpha=alpha)
+    out <- ci_isochron(out)
     if (model==1){
         out$age['disp[t]'] <- out$fact*get.PD.age(out$b['b'],
                               sqrt(out$mswd)*out$b['s[b]'],
@@ -734,38 +789,21 @@ isochron_PD <- function(x,nuclide,xlim=NA,ylim=NA,alpha=0.05,
     out$y0label <-
         substitute(a*b*c,list(a='(',b=y.lab,c=quote(')'[o]*' = ')))
     if (plot){
-        scatterplot(out$d,xlim=xlim,ylim=ylim,alpha=alpha,
+        scatterplot(d,xlim=xlim,ylim=ylim,alpha=alpha,
                     show.ellipses=1*(model!=2),
                     show.numbers=show.numbers,levels=levels,
                     clabel=clabel,ellipse.col=ellipse.col,fit=out,
-                    ci.col=ci.col,line.col=line.col,lwd=lwd,...)
+                    ci.col=ci.col,line.col=line.col,lwd=lwd,
+                    hide=hide,omit=omit,...)
         graphics::title(isochrontitle(out,sigdig=sigdig,type='PD'),
                         xlab=x.lab,ylab=y.lab)
     }
     invisible(out)
 }
 
-isochron_init <- function(x,model=1,inverse=FALSE,alpha=0.05,
-                          osmond=TRUE,type=2,exterr=TRUE,format=1){
-    if (hasClass(x,'ThU') && x$format<3){ # 3D regression 
-        d <- data2tit(x,osmond=osmond)
-        out <- regression(d,model=model,type="titterington")
-    } else if (hasClass(x,'ThU') && x$format>2){ # 2D regression
-        d <- data2york(x,type=type)
-        out <- regression(d,model=model,type="york")
-    } else if (hasClass(x,'PD')){
-        d <- data2york(x,exterr=exterr)
-        out <- regression(d,model=model)
-    } else if (hasClass(x,'KCa')){
-        d <- data2york(x)
-        out <- regression(d,model=model)
-    } else {
-        d <- data2york(x,inverse=inverse)
-        out <- regression(d,model=model)
-    }
-    if (hasClass(x,'linear')){
-        # do nothing
-    } else if (model==1){
+isochron_init <- function(fit,alpha=0.05){
+    out <- fit
+    if (fit$model==1){
         out$age <- rep(NA,4)
         out$y0 <- rep(NA,4)
         names(out$age) <- c('t','s[t]','ci[t]','disp[t]')
@@ -776,23 +814,22 @@ isochron_init <- function(x,model=1,inverse=FALSE,alpha=0.05,
         names(out$age) <- c('t','s[t]','ci[t]')
         names(out$y0) <- c('y','s[y]','ci[y]')
     }
-    if (out$model < 3){
-        out$fact <- tfact(alpha,out$df)
+    if (fit$model < 3){
+        out$fact <- tfact(alpha,fit$df)
     } else {
         out$fact <- nfact(alpha)
         out$w <- c(out$w,NA,NA)
         names(out$w) <- c('s','ll','ul')
     }
+    out$alpha <- alpha
     class(out) <- "isochron"
     out
 }
-regression_init <- function(X,model=model,alpha=0.05){
-    fit <- regression(X,model=model)
+regression_init <- function(fit,alpha=0.05){
     out <- fit
-    out$n <- nrow(X)
     out$displabel <- quote('y-dispersion = ')
     out$y0label <- quote('y-intercept = ')
-    if (model==1){
+    if (fit$model==1){
         out$a <- rep(NA,4)
         out$b <- rep(NA,4)
         names(out$a) <- c('a','s[a]','ci[a]','disp[a]')
@@ -803,40 +840,32 @@ regression_init <- function(X,model=model,alpha=0.05){
         names(out$a) <- c('a','s[a]','ci[a]')
         names(out$b) <- c('b','s[b]','ci[b]')
     }
-    if (out$model < 3){
-        out$fact <- tfact(alpha,out$df)
+    if (fit$model < 3){
+        out$fact <- tfact(alpha,fit$df)
     } else {
         out$fact <- nfact(alpha)
-        out$w <- c(out$w,NA,NA)
+        out$w <- c(fit$w,NA,NA)
         names(out$w) <- c('s','ll','ul')
     }
     out$a[c('a','s[a]')] <- fit$a[c('a','s[a]')]
     out$b[c('b','s[b]')] <- fit$b[c('b','s[b]')]
-    out$a['ci[a]'] <- out$fact*out$a['s[a]']
-    out$b['ci[b]'] <- out$fact*out$b['s[b]']
+    out$a['ci[a]'] <- out$fact*fit$a['s[a]']
+    out$b['ci[b]'] <- out$fact*fit$b['s[b]']
     if (out$model==1){
-        out$a['disp[a]'] <- out$fact*sqrt(out$mswd)*out$a['s[a]']
-        out$b['disp[b]'] <- out$fact*sqrt(out$mswd)*out$b['s[b]']
+        out$a['disp[a]'] <- out$fact*sqrt(fit$mswd)*fit$a['s[a]']
+        out$b['disp[b]'] <- out$fact*sqrt(fit$mswd)*fit$b['s[b]']
     }
+    out$alpha <- alpha
     class(out) <- "isochron"
     out
 }
 
-get.limits <- function(X,sX){
-    minx <- min(X-3*sX,na.rm=TRUE)
-    maxx <- max(X+3*sX,na.rm=TRUE)
+get.limits <- function(x,sx){
+    minx <- min(x-3*sx,na.rm=TRUE)
+    maxx <- max(x+3*sx,na.rm=TRUE)
     c(minx,maxx)
 }
 
-plot_isochron_line <- function(fit,x,ci.col='gray80',...){
-    y <- fit$a[1]+fit$b[1]*x
-    e <- fit$fact*sqrt(fit$a[2]^2 + 2*x*fit$cov.ab + (fit$b[2]*x)^2)
-    cix <- c(x,rev(x))
-    ciy <- c(y+e,rev(y-e))
-    graphics::polygon(cix,ciy,col=ci.col,border=NA)
-    graphics::lines(x,y,...)
-}
-
 plot_PbPb_evolution <- function(tt,inverse=TRUE){
     nn <- 50
     tijd <- seq(0,tt,length.out=nn)
@@ -847,7 +876,6 @@ plot_PbPb_evolution <- function(tt,inverse=TRUE){
     xy <- stacey.kramers(ticks,inverse=inverse)
     graphics::points(xy[,1],xy[,2],pch=20)
     graphics::text(xy[,1],xy[,2],labels=ticks,pos=3)
-
 }
 
 isochrontitle <- function(fit,sigdig=2,type=NA,units="Ma",...){
