@@ -57,6 +57,7 @@
 #'     If \code{levels=NA}, then only the first colour is used. If
 #'     \code{levels} is a vector of numbers, then \code{bg} is used to
 #'     construct a colour ramp.
+#' @param col text colour to be used if \code{show.numbers=TRUE}
 #' @param title add a title to the plot?
 #' @param k number of peaks to fit using the finite mixture models of
 #'     Galbraith and Laslett (1993). Setting \code{k='auto'}
@@ -69,6 +70,12 @@
 #'     plot.
 #' @param alpha cutoff value for confidence intervals
 #' @param units measurement units to be displayed in the legend.
+#' @param hide vector with indices of aliquots that should be removed
+#'     from the radial plot.
+#' @param omit vector with indices of aliquots that should be plotted
+#'     but omitted from the central age calculation or mixture models.
+#' @param omit.col colour that should be used for the omitted
+#'     aliquots.
 #' @param ... additional arguments to the generic \code{points}
 #'     function
 #' @seealso \code{\link{peakfit}}, \code{\link{central}}
@@ -99,16 +106,29 @@ radialplot <- function(x,...){ UseMethod("radialplot",x) }
 radialplot.default <- function(x,from=NA,to=NA,t0=NA,
                                transformation='log',sigdig=2,
                                show.numbers=FALSE,pch=21,levels=NA,
-                               clabel="",bg=c("white","red"),
-                               title=TRUE,k=0,markers=NULL,
-                               alpha=0.05,units='',...){
-    peaks <- peakfit(x,k=k,sigdig=sigdig)
+                               clabel="",bg=c("yellow","red"),col='black',
+                               title=TRUE,k=0,markers=NULL,alpha=0.05,
+                               units='',hide=NA,omit=NA,omit.col=NA,...){
+    x <- x[,c(1,2)]
+    ns <- nrow(x)
+    calcit <- (1:ns)%ni%c(hide,omit)
+    plotit <- (1:ns)%ni%hide
+    x2calc <- clear(x,hide,omit)
+    x2plot <- clear(x,hide)
+    peaks <- peakfit(x2calc,k=k,sigdig=sigdig)
     markers <- c(markers,peaks$peaks['t',])
-    X <- x2zs(x,t0=t0,from=from,to=to,transformation=transformation)
-    radial.plot(X,show.numbers=show.numbers,pch=pch,levels=levels,
-                clabel=clabel,bg=bg,markers=markers,...)
+    X <- x2zs(x2plot,t0=t0,from=from,to=to,transformation=transformation)
+    pcol <- set.ellipse.colours(ns=ns,levels=levels,col=bg,hide=hide,
+                                omit=omit,omit.col=omit.col)
+    tcol <- rep(col,ns)
+    tcol[omit] <- 'grey'
+    radial.plot(X,show.numbers=show.numbers,pch=pch,
+                levels=levels[plotit],clabel=clabel,markers=markers,
+                bg=pcol[plotit],col=tcol[plotit],sn=(1:ns)[plotit],...)
+    colourbar(z=levels[calcit],col=bg,clabel=clabel)
     if (title)
-        title(radial.title(x,sigdig=sigdig,alpha=alpha,units=units,n=nrow(x)))
+        title(radial.title(x2calc,sigdig=sigdig,alpha=alpha,
+                           units=units,n=nrow(x2calc)))
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
 }
@@ -117,20 +137,35 @@ radialplot.default <- function(x,from=NA,to=NA,t0=NA,
 #' @rdname radialplot
 #' @export
 radialplot.fissiontracks <- function(x,from=NA,to=NA,t0=NA,
-                                     transformation='arcsin',
-                                     sigdig=2,show.numbers=FALSE,
-                                     pch=21,levels=NA,clabel="",
-                                     bg=c("white","red"),title=TRUE,
-                                     markers=NULL,k=0,exterr=TRUE,
-                                     alpha=0.05,...){
-    peaks <- peakfit(x,k=k,exterr=exterr,sigdig=sigdig)
+                                     transformation='arcsin',sigdig=2,
+                                     show.numbers=FALSE,pch=21,
+                                     levels=NA,clabel="",
+                                     bg=c("yellow","red"),col='black',
+                                     title=TRUE,markers=NULL,k=0,
+                                     exterr=TRUE,alpha=0.05,hide=NULL,
+                                     omit=NULL,omit.col=NA,...){
+    ns <- length(x)
+    calcit <- (1:ns)%ni%c(hide,omit)
+    plotit <- (1:ns)%ni%hide
+    x2calc <- clear(x,hide,omit)
+    x2plot <- clear(x,hide)
+    peaks <- peakfit(x2calc,k=k,exterr=exterr,sigdig=sigdig)
     markers <- c(markers,peaks$peaks['t',])
-    X <- x2zs(x,t0=t0,from=from,to=to,transformation=transformation)
+    X <- x2zs(x2plot,t0=t0,from=from,to=to,transformation=transformation)
+    pcol <- set.ellipse.colours(ns=ns,levels=levels[plotit],
+                                col=bg,hide=hide,omit=omit,
+                                omit.col=omit.col)
+    tcol <- rep(col,ns)
+    tcol[omit] <- 'grey'
     radial.plot(X,zeta=x$zeta[1],rhoD=x$rhoD[1],
-                show.numbers=show.numbers,pch=pch,levels=levels,
-                clabel=clabel,bg=bg,markers=markers,...)
+                show.numbers=show.numbers,pch=pch,
+                levels=levels[plotit],clabel=clabel,
+                bg=pcol[plotit],col=tcol[plotit],
+                sn=(1:ns)[plotit],...)
+    colourbar(z=levels[calcit],col=bg,clabel=clabel)
     if (title)
-        title(radial.title(x,sigdig=sigdig,alpha=alpha,units='Ma',n=length(x)))
+        title(radial.title(x2calc,sigdig=sigdig,alpha=alpha,
+                           units='Ma',n=length(x2calc)))
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
 }
@@ -171,9 +206,10 @@ radialplot.UPb <- function(x,from=NA,to=NA,t0=NA,
                            transformation='log',type=4,
                            cutoff.76=1100,cutoff.disc=c(-15,5),
                            show.numbers=FALSE,pch=21,levels=NA,
-                           clabel="",bg=c("white","red"),
+                           clabel="",bg=c("yellow","red"),col='black',
                            markers=NULL,k=0,exterr=TRUE,common.Pb=0,
-                           alpha=0.05,...){
+                           alpha=0.05,hide=NULL,omit=NULL,
+                           omit.col=NA,...){
     if (common.Pb %in% c(1,2,3))
         X <- common.Pb.correction(x,option=common.Pb)
     else
@@ -182,8 +218,9 @@ radialplot.UPb <- function(x,from=NA,to=NA,t0=NA,
                       transformation=transformation,type=type,
                       cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,markers=markers,k=k,
-                      exterr=exterr,alpha=alpha,...)
+                      clabel=clabel,bg=bg,col=col,markers=markers,
+                      k=k,exterr=exterr,alpha=alpha,hide=hide,
+                      omit=omit,omit.col=omit.col,...)
 }
 #' @param i2i `isochron to intercept': calculates the initial (aka
 #'     `inherited', `excess', or `common')
@@ -198,9 +235,10 @@ radialplot.UPb <- function(x,from=NA,to=NA,t0=NA,
 #' @export
 radialplot.PbPb <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
-                            pch=21,levels=NA,clabel="",
-                            bg=c("white","red"),markers=NULL,k=0,
-                            exterr=TRUE,common.Pb=1,alpha=0.05,...){
+                            pch=21,levels=NA,clabel="",bg=c("yellow","red"),
+                            col='black',markers=NULL,k=0,
+                            exterr=TRUE,common.Pb=1,alpha=0.05,
+                            hide=NULL,omit=NULL,omit.col=NA,...){
     if (common.Pb %in% c(1,2,3))
         X <- common.Pb.correction(x,option=common.Pb)
     else
@@ -208,99 +246,120 @@ radialplot.PbPb <- function(x,from=NA,to=NA,t0=NA,
     radialplot_helper(X,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,markers=markers,k=k,
-                      exterr=exterr,alpha=alpha,...)
+                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+                      exterr=exterr,alpha=alpha,hide=hide,omit=omit,
+                      omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.ArAr <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",
-                            bg=c("white","red"),markers=NULL,k=0,
-                            exterr=TRUE,i2i=FALSE,alpha=0.05,...){
+                            bg=c("yellow","red"),col='black',
+                            markers=NULL,k=0,exterr=TRUE,i2i=FALSE,
+                            alpha=0.05,hide=NULL,omit=NULL,
+                            omit.col=NA,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+                      omit=omit,omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.KCa <- function(x,from=NA,to=NA,t0=NA,
                            transformation='log',show.numbers=FALSE,
                            pch=21,levels=NA,clabel="",
-                           bg=c("white","red"),markers=NULL,k=0,
-                           exterr=TRUE,i2i=FALSE,alpha=0.05,...){
+                           bg=c("yellow","red"),col='black',
+                           markers=NULL,k=0,exterr=TRUE,i2i=FALSE,
+                           alpha=0.05,hide=NULL,omit=NULL,
+                           omit.col=NA,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+                      omit=omit,omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.UThHe <- function(x,from=NA,to=NA,t0=NA,
                              transformation='log',show.numbers=FALSE,
                              pch=21,levels=NA,clabel="",
-                             bg=c("white","red"),markers=NULL,k=0,
-                             alpha=0.05,...){
+                             bg=c("yellow","red"),col='black',
+                             markers=NULL,k=0,alpha=0.05,
+                             hide=NULL,omit=NULL,omit.col=NA,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,markers=markers,k=k,
-                      exterr=FALSE,alpha=alpha,...)
+                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+                      exterr=FALSE,alpha=alpha,hide=hide,omit=omit,
+                      omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.ReOs <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",
-                            bg=c("white","red"),markers=NULL,k=0,
-                            exterr=TRUE,i2i=TRUE,alpha=0.05,...){
+                            bg=c("yellow","red"),col='black',
+                            markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
+                            alpha=0.05,hide=NULL,omit=NULL,
+                            omit.col=NA,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+                      omit=omit,omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.SmNd <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",
-                            bg=c("white","red"),markers=NULL,k=0,
-                            exterr=TRUE,i2i=TRUE,alpha=0.05,...){
+                            bg=c("yellow","red"),col='black',
+                            markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
+                            alpha=0.05,hide=NULL,omit=NULL,
+                            omit.col=NA,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+                      omit=omit,omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.RbSr <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",
-                            bg=c("white","red"),markers=NULL,k=0,
-                            exterr=TRUE,i2i=TRUE,alpha=0.05,...){
+                            bg=c("yellow","red"),col='black',
+                            markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
+                            alpha=0.05,hide=NULL,omit=NULL,
+                            omit.col=NA,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+                      omit=omit,omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.LuHf <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",
-                            bg=c("white","red"),markers=NULL,k=0,
-                            exterr=TRUE,i2i=TRUE,alpha=0.05,...){
+                            bg=c("yellow","red"),col='black',
+                            markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
+                            alpha=0.05,hide=NULL,omit=NULL,
+                            omit.col=NA,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+                      omit=omit,omit.col=omit.col,...)
 }
 #' @param detritus detrital \eqn{^{230}}Th correction (only applicable
 #'     when \code{x$format == 1} or \code{2}.
@@ -329,34 +388,38 @@ radialplot.LuHf <- function(x,from=NA,to=NA,t0=NA,
 radialplot.ThU <- function(x,from=NA,to=NA,t0=NA,
                            transformation='log',show.numbers=FALSE,
                            pch=21,levels=NA,clabel="",
-                           bg=c("white","red"),markers=NULL,k=0,
-                           i2i=TRUE,alpha=0.05,detritus=0,Th02=c(0,0),
-                           Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
+                           bg=c("yellow","red"),col='black',markers=NULL,
+                           k=0,i2i=TRUE,alpha=0.05,detritus=0,
+                           Th02=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),
+                           hide=NULL,omit=NULL,omit.col=NA,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,markers=markers,k=k,
+                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
                       exterr=FALSE,i2i=i2i,alpha=alpha,units='ka',
-                      detritus=detritus,Th02=Th02,Th02U48=Th02U48,...)
+                      detritus=detritus,Th02=Th02,Th02U48=Th02U48,
+                      hide=hide,omit=omit,omit.col=omit.col,...)
 }
 radialplot_helper <- function(x,from=NA,to=NA,t0=NA,
                               transformation='log',type=4,
                               cutoff.76=1100,cutoff.disc=c(-15,5),
                               show.numbers=FALSE,pch=21,levels=NA,
-                              clabel="",bg=c("white","red"),
+                              clabel="",bg=c("yellow","red"),col='black',
                               markers=NULL,k=0,exterr=TRUE,i2i=FALSE,
                               alpha=0.05,units='Ma',detritus=0,Th02=c(0,0),
-                              Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
-    peaks <- peakfit(x,k=k,exterr=exterr,i2i=i2i,type=type,
+                              Th02U48=c(0,0,1e6,0,0,0,0,0,0),
+                              hide=NULL,omit=NULL,omit.col=NA,...){
+    x2calc <- clear(x,hide,omit)
+    peaks <- peakfit(x2calc,k=k,exterr=exterr,i2i=i2i,type=type,
                      cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
                      detritus=detritus,Th02=Th02,Th02U48=Th02U48)
     markers <- c(markers,peaks$peaks['t',])
     age2radial(x,from=from,to=to,t0=t0,transformation=transformation,
                type=type,cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
                show.numbers=show.numbers,pch=pch,levels=levels,
-               clabel=clabel,bg=bg,markers=markers,i2i=i2i,
+               clabel=clabel,bg=bg,col=col,markers=markers,i2i=i2i,
                alpha=alpha,units=units,detritus=detritus,Th02=Th02,
-               Th02U48=Th02U48,...)
+               Th02U48=Th02U48,hide=hide,omit=omit,omit.col=omit.col,...)
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
 }
@@ -364,23 +427,27 @@ radialplot_helper <- function(x,from=NA,to=NA,t0=NA,
 age2radial <- function(x,from=NA,to=NA,t0=NA,transformation='log',
                        type=4,cutoff.76=1100,cutoff.disc=c(-15,5),
                        show.numbers=FALSE,pch=21,levels=NA,clabel="",
-                       bg=c("white","red"),markers=NULL,k=0,
-                       i2i=FALSE,alpha=0.05,units='MA',detritus=0,
-                       Th02=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
+                       bg=c("yellow","red"),col='black',markers=NULL,
+                       k=0,i2i=FALSE,alpha=0.05,units='MA',detritus=0,
+                       Th02=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),
+                       hide=NULL,omit=NULL,omit.col=NA,...){
     tt <- get.ages(x,type=type,cutoff.76=cutoff.76,
                    cutoff.disc=cutoff.disc,i2i=i2i,
                    detritus=detritus,Th02=Th02,Th02U48=Th02U48)
     radialplot.default(tt,from=from,to=to,t0=t0,
                        transformation=transformation,
                        show.numbers=show.numbers,pch=pch,
-                       levels=levels,clabel=clabel,bg=bg,
-                       markers=markers,alpha=alpha,
-                       units=units,...)
+                       levels=levels,clabel=clabel,bg=bg,col=col,
+                       markers=markers,alpha=alpha,units=units,
+                       hide=hide,omit=omit,omit.col=omit.col,...)
 }
 
 radial.plot <- function(x,zeta=0,rhoD=0,asprat=3/4,
                         show.numbers=FALSE,levels=NA,clabel="",
-                        bg=c('white','red'),markers=NULL,...){
+                        markers=NULL,pch=21,bg='yellow',col='black',
+                        sn=1:length(x$z),...){
+    if (show.numbers & all(is.na(levels))) show.points <- FALSE
+    else show.points <- TRUE
     exM <- radial.scale(x,zeta,rhoD)
     tticks <- get.radial.tticks(x)
     labelpos <- 4
@@ -392,23 +459,26 @@ radial.plot <- function(x,zeta=0,rhoD=0,asprat=3/4,
                           zeta,rhoD,label=FALSE)
     }
     plot_radial_axes(x)
-    ns <- length(x$z)
-    cols <- set.ellipse.colours(ns=ns,levels=levels,col=bg)
-    plot_radial_points(x,show.numbers=show.numbers,bg=cols,...)
-    colourbar(z=levels,col=bg,clabel=clabel)
+    plot_radial_points(x,show.points=show.points,
+                       show.numbers=show.numbers,
+                       pch=pch,bg=bg,col=col,sn=sn,...)
 }
 
-plot_radial_points <- function(x,show.numbers=FALSE,bg='white',...){
+plot_radial_points <- function(x,show.points=TRUE,show.numbers=FALSE,
+                               bg='yellow',pch=21,col='black',
+                               sn=1:length(x$z),...){
     rxy <- data2rxry(x)
     rx <- rxy[,1]
     ry <- rxy[,2]
-    if (show.numbers) {
-        graphics::text(rx,ry,1:length(rx),...)
-    } else if ('pch' %in% names(list(...))){
-        graphics::points(rx,ry,bg=bg,...)
-    } else {
-        graphics::points(rx,ry,bg=bg,pch=21,...)
+    if (show.numbers & show.points){
+        graphics::text(rx,ry,labels=sn,pos=1)
+    } else if (show.numbers){
+        graphics::text(rx,ry,labels=sn,col=col)
     }
+    if (show.points){
+        graphics::points(rx,ry,bg=bg,pch=pch,...)
+    }
+
 }
 
 plot_radial_axes <- function(x,...){
@@ -715,10 +785,10 @@ radial.title <- function(x,sigdig=2,alpha=0.05,units='',n=length(x),...){
                              c=rounded.age[3],
                              d=units,
                              n=n))
-    line2 <- substitute('MSWD ='~a~', p('~chi^2*')='~b,
+    line2 <- substitute('MSWD ='~a*', p('*chi^2*') ='~b,
                         list(a=signif(fit$mswd,sigdig),
                              b=signif(fit$p.value,sigdig)))
-    line3 <- substitute('dispersion ='~a+b/-c~'%',
+    line3 <- substitute('dispersion ='~a+b/-c*'%',
                         list(a=rounded.disp[1],
                              b=rounded.disp[3],
                              c=rounded.disp[2]))
